@@ -1,22 +1,20 @@
 /*
- fixedCodebookSearch.c
-
- Copyright (C) 2011 Belledonne Communications, Grenoble, France
- Author : Johan Pascal
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * Copyright (c) 2011-2019 Belledonne Communications SARL.
+ *
+ * This file is part of bcg729.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "typedef.h"
@@ -62,7 +60,7 @@ void fixedCodebookSearch(word16_t targetSignal[], word16_t impulseResponse[], in
 	int correlationSignalSign[L_SUBFRAME]; /* to store the sign of each correlationSignal element */
 	/* build the matrix Ф' : impulseResponse correlation matrix spec 3.8.1 eq51, eq56 and eq57 */
 	/* correlationSignal turns to absolute values and sign of elements is stored in correlationSignalSign */
-	word32_t Phi[L_SUBFRAME][L_SUBFRAME];
+	word32_t Phi[L_SUBFRAME][L_SUBFRAME] = {{0}};
 	int m3Base;
 	int i0=0, i1=0, i2=0, i3=0;
 	word32_t correlationSquareMax = -1;
@@ -209,10 +207,10 @@ void fixedCodebookSearch(word16_t targetSignal[], word16_t impulseResponse[], in
 	}
 
 	/* set the four pulses, in Q13 */
-	fixedCodebookVector[i0] = SHL((word16_t)correlationSignalSign[i0], 13); 
-	fixedCodebookVector[i1] = SHL((word16_t)correlationSignalSign[i1], 13); 
-	fixedCodebookVector[i2] = SHL((word16_t)correlationSignalSign[i2], 13); 
-	fixedCodebookVector[i3] = SHL((word16_t)correlationSignalSign[i3], 13); 
+	fixedCodebookVector[i0] = SSHL((word16_t)correlationSignalSign[i0], 13);
+	fixedCodebookVector[i1] = SSHL((word16_t)correlationSignalSign[i1], 13);
+	fixedCodebookVector[i2] = SSHL((word16_t)correlationSignalSign[i2], 13);
+	fixedCodebookVector[i3] = SSHL((word16_t)correlationSignalSign[i3], 13);
 
 	/* adapt it according to eq48 */
 	for (i=intPitchDelay; i<L_SUBFRAME; i++) {
