@@ -1,22 +1,20 @@
 /*
- gainQuantization.c
-
- Copyright (C) 2011 Belledonne Communications, Grenoble, France
- Author : Johan Pascal
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * Copyright (c) 2011-2019 Belledonne Communications SARL.
+ *
+ * This file is part of bcg729.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "typedef.h"
@@ -144,7 +142,7 @@ void gainQuantization(bcg729EncoderChannelContextStruct *encoderChannelContext,
 		numeratorH = (numeratorH>0)?numeratorH:-numeratorH;
 		numeratorNorm = countLeadingZeros(numeratorH);
 		if (numeratorNorm >= 9) {
-			bestAdaptativeCodebookGain = (word32_t)(DIV64(SHL64(numerator,9), denominator)); /* bestAdaptativeCodebookGain in Q9 */
+			bestAdaptativeCodebookGain = (word32_t)(DIV64(SSHL64(numerator,9), denominator)); /* bestAdaptativeCodebookGain in Q9 */
 		} else {
 			word64_t shiftedDenominator = SHR64(denominator, 9-numeratorNorm);
 			if (shiftedDenominator>0) { /* can't shift left by 9 the numerator, can we shift right by 9-numeratorNorm the denominator without hiting 0 */
@@ -161,7 +159,7 @@ void gainQuantization(bcg729EncoderChannelContextStruct *encoderChannelContext,
 		numeratorNorm = countLeadingZeros(numeratorH);
 
 		if (numeratorNorm >= 14) {
-			bestFixedCodebookGain = (word32_t)(DIV64(SHL64(numerator,14), denominator)); 
+			bestFixedCodebookGain = (word32_t)(DIV64(SSHL64(numerator,14), denominator));
 		} else {
 			word64_t shiftedDenominator = SHR64(denominator, 14-numeratorNorm); /* bestFixedCodebookGain in Q14 */
 			if (shiftedDenominator>0) { /* can't shift left by 9 the numerator, can we shift right by 9-numeratorNorm the denominator without hiting 0 */
@@ -192,9 +190,9 @@ void gainQuantization(bcg729EncoderChannelContextStruct *encoderChannelContext,
 	if (indexBaseGb>0) indexBaseGb--;
 
 	/*** test all possibilities of Ga and Gb indexes and select the best one ***/
-	xy = -SHL(xy,1); /* xy term is always used with a -2 factor */
-	xz = -SHL(xz,1); /* xz term is always used with a -2 factor */
-	yz = SHL(yz,1); /* yz term is always used with a 2 factor */
+	xy = -SSHL(xy,1); /* xy term is always used with a -2 factor */
+	xz = -SSHL(xz,1); /* xz term is always used with a -2 factor */
+	yz = SSHL(yz,1); /* yz term is always used with a 2 factor */
 
 	for (i=0; i<4; i++) {
 		for (j=0; j<8; j++) {
