@@ -1,22 +1,20 @@
 /*
- postFilter.c
-
- Copyright (C) 2011 Belledonne Communications, Grenoble, France
- Author : Johan Pascal
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * Copyright (c) 2011-2019 Belledonne Communications SARL.
+ *
+ * This file is part of bcg729.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 #include <string.h>
 
@@ -62,7 +60,6 @@ void postFilter(bcg729DecoderChannelContextStruct *decoderChannelContext, word16
 	word16_t *residualSignal;
 	word16_t *scaledResidualSignal;
 	word32_t correlationMax = (word32_t)MININT32;
-	int16_t intPitchDelayMax;
 	int16_t bestIntPitchDelay = 0;
 	word16_t *delayedResidualSignal;
 	word32_t residualSignalEnergy = 0; /* in Q-4 */
@@ -103,7 +100,7 @@ void postFilter(bcg729DecoderChannelContextStruct *decoderChannelContext, word16
 	scaledResidualSignal = &(decoderChannelContext->scaledResidualSignalBuffer[MAXIMUM_INT_PITCH_DELAY+subframeIndex]);
 
 	for (i=0; i<L_SUBFRAME; i++) {
-		word32_t acc = SHL((word32_t)reconstructedSpeech[i], 12); /* reconstructedSpeech in Q0 shifted to set acc in Q12 */
+		word32_t acc = SSHL((word32_t)reconstructedSpeech[i], 12); /* reconstructedSpeech in Q0 shifted to set acc in Q12 */
 		for (j=0; j<NB_LSP_COEFF; j++) {
 			acc = MAC16_16(acc, LPGammaNCoefficients[j],reconstructedSpeech[i-j-1]); /* LPGammaNCoefficients in Q12, reconstructedSpeech in Q0 -> acc in Q12 */
 		}
@@ -113,12 +110,11 @@ void postFilter(bcg729DecoderChannelContextStruct *decoderChannelContext, word16
 
 	/*** Compute the maximum correlation on scaledResidualSignal delayed by intPitchDelay +/- 3 to get the best delay. Spec 4.2.1 eq80 ***/
 	/* using a scaled(Q-2) signals gives correlation in Q-4. */
-	intPitchDelayMax = intPitchDelay+3; /* intPitchDelayMax shall be < MAXIMUM_INT_PITCH_DELAY(143) */
-	if (intPitchDelayMax>MAXIMUM_INT_PITCH_DELAY) {
-		intPitchDelayMax = MAXIMUM_INT_PITCH_DELAY;
+	if (intPitchDelay>MAXIMUM_INT_PITCH_DELAY-3) { /* intPitchDelay shall be < MAXIMUM_INT_PITCH_DELAY-3 (140) */
+		intPitchDelay = MAXIMUM_INT_PITCH_DELAY-3;
 	}
 
-	for (i=intPitchDelay-3; i<=intPitchDelayMax; i++) {
+	for (i=intPitchDelay-3; i<=intPitchDelay+3; i++) {
 		word32_t correlation = 0;
 		delayedResidualSignal = &(scaledResidualSignal[-i]); /* delayedResidualSignal points to scaledResidualSignal[-i] */
 		
@@ -223,7 +219,7 @@ void postFilter(bcg729DecoderChannelContextStruct *decoderChannelContext, word16
 
 	hf[0] = 4096; /* 1 in Q12 as LPGammaNCoefficients and LPGammaDCoefficient doesn't contain the first element which is 1 and past values of hf are 0 */
 	for (i=1; i<11; i++) {
-		word32_t acc = (word32_t)SHL(LPGammaNCoefficients[i-1],12); /* LPGammaNCoefficients in Q12 -> acc in Q24 */
+		word32_t acc = (word32_t)SSHL(LPGammaNCoefficients[i-1],12); /* LPGammaNCoefficients in Q12 -> acc in Q24 */
 		for (j=0; j<NB_LSP_COEFF && j<i; j++) { /* j<i to avoid access to negative index of hf(past values are 0 anyway) */
 			acc = MSU16_16(acc, LPGammaDCoefficients[j], hf[i-j-1]); /* LPGammaDCoefficient in Q12, hf in Q12 -> Q24 TODO: Possible overflow?? */
 		}
