@@ -1,22 +1,20 @@
 /*
- utils.c
-
- Copyright (C) 2011 Belledonne Communications, Grenoble, France
- Author : Johan Pascal
- 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * Copyright (c) 2011-2019 Belledonne Communications SARL.
+ *
+ * This file is part of bcg729.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "typedef.h"
@@ -133,7 +131,7 @@ void synthesisFilter(word16_t inputSignal[], word16_t filterCoefficients[], word
 {
 	int i;
 	for (i=0; i<L_SUBFRAME; i++) {
-		word32_t acc = SHL(inputSignal[i],12); /* acc get the first term of the sum, in Q12 (inputSignal is in Q0)*/
+		word32_t acc = SSHL(inputSignal[i],12); /* acc get the first term of the sum, in Q12 (inputSignal is in Q0)*/
 		int j;
 		for (j=0; j<NB_LSP_COEFF; j++) {
 			acc = MSU16_16(acc, filterCoefficients[j], filteredSignal[i-j-1]); /* filterCoefficients in Q12 and signal in Q0 -> acc in Q12 */
@@ -347,7 +345,7 @@ void CNGparametersArray2BitStream(uint16_t parameters[], uint8_t bitStream[]) {
 /*      -(o) parameters : 16 values parameters array                         */
 /*                                                                           */
 /*****************************************************************************/
-void parametersBitStream2Array(uint8_t bitStream[], uint16_t parameters[])
+void parametersBitStream2Array(const uint8_t bitStream[], uint16_t parameters[])
 {
 	parameters[0] = (bitStream[0]>>7)&(uint16_t)0x1;
 	parameters[1] = bitStream[0]&(uint16_t)0x7f;
